<?php
/**
 * Contains only basic static methods for Albireo
 * @package    Albireo I
 * @subpackage Core
 * @copyright  Copyright (c) 2009 Albireo Solutions. All rights reserved
 * @license    GNU/AGPL http://www.gnu.org/licenses/agpl.html
 *
 * Albireo is free software! You can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU Affero General Public License for more details.
 */
class Tools {

    private static $BaseSettings;

    /**
     * gets requested page file
     * @return String
     */
    public static function getPage () {
	if ( isset ( $_GET [ "page" ] ) ) {
	    return addslashes ( urldecode ( $_GET [ "page" ] ) );
	} else {
	    return Localization::session() -> getLanguage () ."_index";
	}
    } // end getPage

    /**
     * gets requested page file including file extension
     * @return String
     */
    public static function getFullPage () {
	if ( isset ( $_GET [ "page" ] ) ) {
	    return addslashes ( urldecode ( $_GET [ "page" ] ) ) . Tools::baseSettings () -> getSetting ( "file_extension" );
	} else {
	    return Localization::session() -> getLanguage () ."_index". Tools::baseSettings () -> getSetting ( "file_extension" );
	}
    } // end getPage

    /**
     * Date converting from database format to human format (czech format)
     * @param String $date database date
     * @param String $type (short|long) short = only date, long = date and time
     * @return String human date
     */
    public static function getRightDate ( $date, $type = "short" ) {
	if ( $type == "short" ) {
	    return intval ( substr ( $date, 8, 2 ) ) .".". intval ( substr ( $date, 5, 2 ) ). ".". substr ( $date, 0, 4 );
	} else { // that meand $type contents "long", "full" or similar thing
	    return intval ( substr ( $date, 8, 2 ) ) .".". intval ( substr ( $date, 5, 2 ) ). ".". substr ( $date, 0, 4 ) ." "
		    . substr ( $date, 11, 8 );
	}
    } // end getRightDate

    /**
     * gets full HTTP address of website (e.g http://www.domain.tld/)
     * @return String
     */
    public static function getHttpAddress () {
	return "http://". $_SERVER [ "HTTP_HOST" ] . substr ( $_SERVER [ "SCRIPT_NAME" ], 0, strrpos ( $_SERVER [ "SCRIPT_NAME" ], "/" ) ) ."/";
    } // end getHttpAddress

    /**
     * gets full HTTPS address of website (e.g https://www.domain.tld/)
     * @return String
     */
    public static function getHttpsAddress () {
	return "https://". $_SERVER [ "HTTP_HOST" ] . substr ( $_SERVER [ "SCRIPT_NAME" ], 0, strrpos ( $_SERVER [ "SCRIPT_NAME" ], "/" ) ) ."/";
    } // end getHttpsAddress

    /**
     * gets instance of Settings for base Albireo settings
     * @return object
     */
    public static function baseSettings () {
	if ( self::$BaseSettings == null ) {
	    self::$BaseSettings = new Settings ( "base-settings" );
	}
	return self::$BaseSettings;
    } // end baseSettings

    /**
     * checks e-mail address validity
     * @param string $email
     * @return boolean
     */
    public static function check_email_address ( $email ) {
	if (empty($email)) {
	    // there are no data
	    return false;
	}
	// First, we check that there's one @ symbol,
	// and that the lengths are right.
	if (!preg_match("/^[^@]{1,64}@[^@]{1,255}$/", $email)) {
	    // Email invalid because wrong number of characters
	    // in one section or wrong number of @ symbols.
	    return false;
	}
	// Split it into sections to make life easier
	$email_array = explode("@", $email);
	$local_array = explode(".", $email_array[0]);
	for ($i = 0; $i < sizeof($local_array); $i++) {
	    if (!preg_match("/^(([A-Za-z0-9!#$%&'*+\/=?^_`{|}~-][A-Za-z0-9!#$%&'*+\/=?^_`{|}~\.-]{0,63})|(\"[^(\\|\")]{0,62}\"))$/",
		$local_array[$i])) {
		return false;
	    }
	}
	// Check if domain is IP. If not,
	// it should be valid domain name
	if (!preg_match("/^\[?[0-9\.]+\]?$/", $email_array[1])) {
	    $domain_array = explode(".", $email_array[1]);
	    if (sizeof($domain_array) < 2) {
		return false; // Not enough parts to domain
	    }
	    for ($i = 0; $i < sizeof($domain_array); $i++) {
		if (!preg_match("/^(([A-Za-z0-9][A-Za-z0-9-]{0,61}[A-Za-z0-9])|([A-Za-z0-9]+))$/",
		    $domain_array[$i])) {
		    return false;
		}
	    }
	}
	// Check DNS records corresponding to a given Internet host name
	if(!checkdnsrr($email_array[1],'MX')) {
	    return false;
	}
	return true;
    }

}
?>